.. _curlobject:

Curl Object
===========

.. autoclass:: pycurl.Curl

    Curl objects have the following methods:

    .. automethod:: pycurl.Curl.close

    .. _setopt:
    .. automethod:: pycurl.Curl.setopt

    .. _perform:
    .. automethod:: pycurl.Curl.perform

    .. _perform_rb:
    .. automethod:: pycurl.Curl.perform_rb

    .. _perform_rs:
    .. automethod:: pycurl.Curl.perform_rs

    .. _getinfo:
    .. automethod:: pycurl.Curl.getinfo

    .. _getinfo_raw:
    .. automethod:: pycurl.Curl.getinfo_raw

    .. automethod:: pycurl.Curl.reset

    .. _unsetopt:
    .. automethod:: pycurl.Curl.unsetopt

    .. automethod:: pycurl.Curl.pause

    .. _errstr:
    .. automethod:: pycurl.Curl.errstr

    .. _errstr_raw:
    .. automethod:: pycurl.Curl.errstr_raw

    .. automethod:: pycurl.Curl.setopt_string
